========
squealer
========


.. image:: https://img.shields.io/pypi/v/squealer.svg
        :target: https://pypi.python.org/pypi/squealer

.. image:: https://img.shields.io/travis/andressl91/squealer.svg
        :target: https://travis-ci.org/andressl91/squealer

.. image:: https://readthedocs.org/projects/squealer/badge/?version=latest
        :target: https://squealer.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Squealer is yet another SQL database wrapper, currently for Sqlite databases.


* Free software: MIT license
* Documentation: https://squealer.readthedocs.io.

Squealer is 

Features
--------

* TODO
  Add support for MySql

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
